close all
clear all
clc

%Install chebfun from  http://www.chebfun.org/ run:
unzip('https://github.com/chebfun/chebfun/archive/master.zip')
movefile('chebfun-master', 'chebfun')
addpath(fullfile(cd,'chebfun'))
savepath

set(0,'defaultaxesfontsize',14)
set(0,'defaultlinelinewidth',2.5) 

ff=@(x) cos(2*pi*x)+x;
t=linspace(0,1,1000);

p_ref=ff(t);
v_ref=diff(p_ref);

t_sparse = linspace(0,1,10)';
f = chebfun(ff(t_sparse),'equi');


%start position
p1=1.5; 
%start velocity
v1=v_ref(1);

%end position
p2=2.5; 
%end velocity
v2=v_ref(end);

%max allowed acceleration
a_lim=100*max(diff(v_ref));

%q1 and q2
q1=0.1;
q2=1;


%phase variable
phaseVar=2:length(v_ref);

%reconstruct chebyshev points
p_rec=f(linspace(-1,1,1000));
v_rec=diff(p_rec);

%gen OCP where
%p_ref is the reference position trajectory
%v_rec is the refernce velocity prfile
%a_lim is the maximal allowed 
%phaseVar acceleration
%q1 is the value for q_1 which describes the influnace of the gain
%controller for any position deviation
%q2 is the value for q_2 which describes the influance of the gain
%controller for any velocity deviation
%p1 is the desired start postion
%v1 is the desired start velocity
%p2 is the desired end postion
%v2 is the desired end velocity
[P V]=gen_2OCP(p_rec,v_rec,a_lim,phaseVar,q1,q2, p1,v1, p2,v2);


figure
hold on
plot(p_ref)
plot(P,'r')
legend('Reference Pos','OCP Pos')
ylabel('position [cm]')
xlabel('time [s]')
title('Position with changed start- and end-point')

figure
hold on
plot(v_ref)
plot(V,'r')
legend('Reference Vel','OCP Vel')
ylabel('velocity [cm/s]')
xlabel('time [s]')
title('Velocity with bound start- and end-velocity')

